#!/usr/bin/env python

import sys

import cocos
from cocos import actions
from cocos.director import director

from const import *
from res import *

def splash(sprite, weight=1, entering=True):
    """Causes a splash in the current scene.

    sprite:
      The sprite causing the splash.

    weight:
      Relative weight of object which is splashing.

    entering:
        True if entering the water otherwise exiting.
    """
    scale = min(abs(sprite.velocity[1]) / 250 * weight * 1 if entering else 0.65, 1)
    ripples = cocos.sprite.Sprite(ripples_image, position=sprite.position)
    ripples.scale = scale
    ripples.opacity = 100
    director.scene.splash_layer.add(ripples, z=100)
    if entering:
        ripples.do((actions.FadeTo(140, 0.2) + actions.FadeOut(1.3)) | (actions.Delay(1.5) + actions.CallFuncS(lambda s: s.kill())))
    else:
        ripples.do((actions.FadeTo(140, 0.2) + actions.FadeOut(0.5)) | (actions.Delay(0.7) + actions.CallFuncS(lambda s: s.kill())))

    if entering:
        splash = cocos.sprite.Sprite(splash_animation, position=sprite.position)
        splash.scale = scale
        director.scene.splash_layer.add(splash)
        splash.do((actions.Delay(.5) + actions.FadeOut(1)) | (actions.Delay(1.5) + actions.CallFuncS(lambda s: s.kill())))

def is_debug():
    return len(sys.argv) > 1 and sys.argv[1].lower() == 'debug'

def required_rings(level):
    return 2 if is_debug() else level + 3

def volume(on):
    music_player.volume = on * MUSIC_VOLUME
