#!/usr/bin/env python

from math import sqrt, radians, asin, sin, cos

def sign(x):
    """Return -1, 0 or +1 if x is -ve, 0 or +ve respectively."""
    return (x > 0) - (x < 0)

def magnitude(v):
    """Return the magnitude of a vector."""
    return sqrt(v[0] ** 2 + v[1] ** 2)

def rect_hit(p, c, r, w, h):
    """Return True if point p is inside rectangle.
    
    Rectangle is defined by centre c, rotation r (degrees), width w and height h.
    """
    dist = sqrt((c[0] - p[0]) ** 2 + (c[1] - p[1]) ** 2)
    if dist == 0:
        return True
    angle = -asin((c[1] - p[1]) / dist)  # negate because cocos2d angles increase clockwise
    adjusted_angle = angle + radians(r)
    adjusted_p = c[0] + cos(adjusted_angle) * dist, c[1] - sin(adjusted_angle) * dist
    return abs(c[0] - p[0]) <= w / 2 and abs(c[1] - p[1]) <= h / 2
